@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import warnings
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -41,7 +42,7 @@ class CandidateInfoNotFound(PdmException):
         super().__init__(message)
 
 
-class PDMWarning(UserWarning):
+class PDMWarning(Warning):
     pass
 
 
@@ -49,6 +50,13 @@ class PackageWarning(PDMWarning):
     pass
 
 
+class PDMDeprecationWarning(PDMWarning, DeprecationWarning):
+    pass
+
+
+warnings.simplefilter("default", category=PDMDeprecationWarning)
+
+
 class ExtrasWarning(PDMWarning):
     def __init__(self, project_name: str, extras: list[str]) -> None:
         super().__init__(f"Extras not found for {project_name}: [{','.join(extras)}]")
@@ -69,7 +77,7 @@ class UninstallError(PdmException):
 
 class NoConfigError(PdmUsageError, KeyError):
     def __str__(self) -> str:
-        return f"Not such config key: {self.args[0]!r}"
+        return f"No such config key: {self.args[0]!r}"
 
 
 class NoPythonVersion(PdmUsageError):
